==> estateplat-common-1.2.3-20180929.060756-195-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJtcy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2017/3/6
 * @description 不动产家庭成员
 */
@Table(name = "bdc_jtcy")
public class BdcJtcy implements Serializable,InsertVo{
    @Id
    private String jtcyid;//家庭成员ID

    private String qlrid;//权利人ID

    private String jtcymc;//家庭成员名称

    private String sfzjzl;//身份证件种类

    private String zjh;//证件号

    private String txdz;//通讯地址

    private String xb;//性别

    private String lxdh;//联系电话

    private Integer xh;//序号

    private String yhzgx;//与户主关系

    private Date gxsj;//更新时间

    private String hkszd;//户口所在地

    public String getJtcyid() {
        return jtcyid;
    }

    public void setJtcyid(String jtcyid) {
        this.jtcyid = jtcyid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getJtcymc() {
        return jtcymc;
    }

    public void setJtcymc(String jtcymc) {
        this.jtcymc = jtcymc;
    }

    public String getSfzjzl() {
        return sfzjzl;
    }

    public void setSfzjzl(String sfzjzl) {
        this.sfzjzl = sfzjzl;
    }

    public String getZjh() {
        return zjh;
    }

    public void setZjh(String zjh) {
        this.zjh = zjh;
    }

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getYhzgx() {
        return yhzgx;
    }

    public void setYhzgx(String yhzgx) {
        this.yhzgx = yhzgx;
    }

    public Date getGxsj() {
        return gxsj;
    }

    public void setGxsj(Date gxsj) {
        this.gxsj = gxsj;
    }

    public String getHkszd() {
        return hkszd;
    }

    public void setHkszd(String hkszd) {
        this.hkszd = hkszd;
    }
}

==> estateplat-common-1.2.4-20210406.005017-698-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJtcy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2017/3/6
 * @description 不动产家庭成员
 */
@Table(name = "bdc_jtcy")
public class BdcJtcy implements Serializable, InsertVo {
    @Id
    private String jtcyid;//家庭成员ID

    private String qlrid;//权利人ID

    private String jtcymc;//家庭成员名称

    private String sfzjzl;//身份证件种类

    private String zjh;//证件号

    private String txdz;//通讯地址

    private String xb;//性别

    private String lxdh;//联系电话

    private Integer xh;//序号

    private String yhzgx;//与户主关系

    private Date gxsj;//更新时间

    private String hkszd;//户口所在地

    private String gljtcyid;//关联家庭成员id


    public String getJtcyid() {
        return jtcyid;
    }

    public void setJtcyid(String jtcyid) {
        this.jtcyid = jtcyid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getJtcymc() {
        return jtcymc;
    }

    public void setJtcymc(String jtcymc) {
        this.jtcymc = jtcymc;
    }

    public String getSfzjzl() {
        return sfzjzl;
    }

    public void setSfzjzl(String sfzjzl) {
        this.sfzjzl = sfzjzl;
    }

    public String getZjh() {
        return zjh;
    }

    public void setZjh(String zjh) {
        this.zjh = zjh;
    }

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getYhzgx() {
        return yhzgx;
    }

    public void setYhzgx(String yhzgx) {
        this.yhzgx = yhzgx;
    }

    public Date getGxsj() {
        return gxsj;
    }

    public void setGxsj(Date gxsj) {
        this.gxsj = gxsj;
    }

    public String getHkszd() {
        return hkszd;
    }

    public void setHkszd(String hkszd) {
        this.hkszd = hkszd;
    }

    public String getGljtcyid() {
        return gljtcyid;
    }

    public void setGljtcyid(String gljtcyid) {
        this.gljtcyid = gljtcyid;
    }
}
